# TriCCo

A library for computing connected components on an unstructured triangular grid.

Authors: 
*  Aiko Voigt (University of Vienna)
*  Petra Schwer (Otto von Guericke University of Magdeburg)
*  Noam von Rotberg (Otto von Guericke University of Magdeburg)
*  Nicole Knopf (Karlsruhe Institute of Technology)

